==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/tests/netedit/additionalelements/parkingspace/inspect/width/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot, ['--gui-testing-debug-gl'])

# go to additional mode
netedit.additionalMode()

# select parkingArea
netedit.changeElement("parkingArea")

# create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 250, 180)

# select space
netedit.changeElement("space")

# create space
netedit.selectAdditionalChild(netedit.attrs.parkingSpace.create.parent, 0)
netedit.leftClick(referencePosition, 231, 285)

# go to inspect mode
netedit.inspectMode()

# inspect space
netedit.leftClick(referencePosition, 230, 275)

# Change parameter width with a non valid value (dummy)
netedit.modifyAttribute(netedit.attrs.parkingSpace.inspect.width, "dummyWidth", False)

# Change parameter width with a non valid value (negative)
netedit.modifyAttribute(netedit.attrs.parkingSpace.inspect.width, "-5", False)

# Change parameter width with a non valid value (0)
netedit.modifyAttribute(netedit.attrs.parkingSpace.inspect.width, "0", False)

# Change parameter width with a valid value
netedit.modifyAttribute(netedit.attrs.parkingSpace.inspect.width, "2.3", False)

# Check undos and redos
netedit.undo(referencePosition, 3)
netedit.redo(referencePosition, 3)

# save additionals
netedit.saveAdditionals(referencePosition)

# save network
netedit.saveNetwork(referencePosition)

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/tests/netedit/additionalelements/parkingspace/inspect/width/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# go to additional mode
netedit.additionalMode()

# select parkingArea
netedit.changeElement("parkingArea")

# create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 475, 256)

# select space
netedit.changeElement("space")

# create space
netedit.selectAdditionalChild(netedit.attrs.parkingSpace.create.parent, 0)
netedit.leftClick(referencePosition, 292, 371)

# go to inspect mode
netedit.inspectMode()

# inspect space
netedit.leftClick(referencePosition, 292, 347)

# Change parameter width with a non valid value (dummy)
netedit.modifyAttribute(netedit.attrs.parkingSpace.inspect.width, "dummyWidth", False)

# Change parameter width with a non valid value (negative)
netedit.modifyAttribute(netedit.attrs.parkingSpace.inspect.width, "-5", False)

# Change parameter width with a non valid value (0)
netedit.modifyAttribute(netedit.attrs.parkingSpace.inspect.width, "0", False)

# Change parameter width with a valid value
netedit.modifyAttribute(netedit.attrs.parkingSpace.inspect.width, "2.3", False)

# Check undos and redos
netedit.undo(referencePosition, 3)
netedit.redo(referencePosition, 3)

# save netedit config
netedit.saveNeteditConfig(referencePosition)

# quit netedit
netedit.quit(neteditProcess)
